BasicTSPL<T extends BasicTSPL<T> > class
abstract
- Inheritance
-
- Object
- PSDK<
T> - BasicTSPL
- Implementers
Constructors
- BasicTSPL({required Lifecycle lifecycle})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
inherited
-
autodot(
{required bool enable}) → T - 虚化 横向实线变成虚线
-
bar(
{required TBar arg}) → T - 画线(只能画横竖线)
-
barcode(
{required TBarCode arg}) → T - 二维码
-
bline(
{int height = 3, int offset = 0}) → T - 黑标纸打印
-
box(
{required TBox arg}) → T - 打印边框
-
circle(
{required TCircle arg}) → T - 画圆
-
cleanFlash(
{required int index}) → T - 清除位图
-
clear(
) → T -
inherited
-
cls(
) → T - 清除页面缓冲区
-
command(
) → Command -
inherited
-
commander(
) → Commander -
Get commander
override
-
connectedDevice(
) → ConnectedDevice -
Get connected device
override
-
continuous(
{int height = 0, int offset = 0}) → T - 连续纸打印
-
cut(
{required bool enable}) → T - 使能切刀 @param enable true:使能 false:不使能
-
density(
{required int density}) → T - 设置浓度
-
detect(
) → T - 学习纸张
-
direction(
{required TDirection arg}) → T - 设置打印方向
-
dmatrix(
{required TDmatrix arg}) → T - 打印二维条码DATAMATRIX
-
ellipse(
{required TEllipse arg}) → T - 画椭圆
-
gap(
{required bool enable}) → T - 定位缝隙
-
getRibbonEnd(
) → T - 获取当前碳尾开关(0关,1开)
-
image(
{required TImage arg}) → T - 打印图片
-
label(
{int height = 3, int offset = 0}) → T - 标签纸打印
-
line(
{required TLine arg}) → T - 画线(能画斜线)
-
mddle(
) → T -
models(
) → T - 热转印的型号获取
-
newline(
) → T -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offset(
{int offset = 0}) → T - 进纸
-
page(
{required TPage arg}) → T - 创建标签页面大小
-
peel(
{required bool enable}) → T - 是否剥去
-
print(
{int copies = 1}) → T - 打印标签 @param copies 打印份数
-
push(
Arg command) → T -
inherited
-
putImage(
{required TPutImage arg}) → T - 打印打印机里缓存的图片
-
qrcode(
{required TQRCode arg}) → T - 二维码
-
raw(
Raw raw) → T -
inherited
-
read(
{ReadOptions? options}) → Stream< Uint8List> -
inherited
-
reference(
{int horizontal = 0, int vertical = 0}) → T - 相对偏移
-
reverse(
{required TReverse arg}) → T - 反色
-
ribbon(
{required bool enable}) → T - 热敏模式
-
selfTest(
) → T - 打印自检页
-
setBlack(
) → T - 黑色打印
-
setGBKCode(
) → T - 打印机设置成gbk编码
-
setRed(
{required int density}) → T - 红色打印(0-15)
-
setRibbonEnd(
bool enable) → T - 设置碳尾开关
-
setUTF8Code(
) → T - 打印机设置成utf-8编码
-
shift(
{int shift = 0}) → T - 垂直偏移
-
sn(
) → T - 查询SN
-
sns(
) → T - 热转印的sn获取
-
speed(
{required int speed}) → T - 设置速度
-
state(
) → T - 查询状态
-
status(
) → T - 查询状态(热敏机器)
-
sversion(
) → String -
inherited
-
tear(
{required bool enable}) → T - 是否撕去
-
text(
{required TText arg}) → T - 打印文本
-
textBox(
{required TTextBox arg}) → T - 打印文本框
-
toString(
) → String -
A string representation of this object.
inherited
-
variable(
String name, Object value) → PSDK< PSDK> -
inherited
-
version(
) → T - 查询版本
-
versions(
) → T - 热转印的版本号获取
-
write(
{WriteOptions? options}) → Future< WroteReporter> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited