GenericTSPL class

Inheritance

Constructors

GenericTSPL({required Lifecycle lifecycle})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authors() List<String>
inherited
autodot({required bool enable}) GenericTSPL
虚化 横向实线变成虚线
inherited
bar({required TBar arg}) GenericTSPL
画线(只能画横竖线)
inherited
barcode({required TBarCode arg}) GenericTSPL
二维码
inherited
bline({int height = 3, int offset = 0}) GenericTSPL
黑标纸打印
inherited
box({required TBox arg}) GenericTSPL
打印边框
inherited
circle({required TCircle arg}) GenericTSPL
画圆
inherited
cleanFlash({required int index}) GenericTSPL
清除位图
inherited
clear() GenericTSPL
inherited
cls() GenericTSPL
清除页面缓冲区
inherited
command() → Command
inherited
commander() → Commander
Get commander
inherited
connectedDevice() → ConnectedDevice
Get connected device
inherited
continuous({int height = 0, int offset = 0}) GenericTSPL
连续纸打印
inherited
cut({required bool enable}) GenericTSPL
使能切刀 @param enable true:使能 false:不使能
inherited
density({required int density}) GenericTSPL
设置浓度
inherited
direction({required TDirection arg}) GenericTSPL
设置打印方向
inherited
dmatrix({required TDmatrix arg}) GenericTSPL
打印二维条码DATAMATRIX
inherited
ellipse({required TEllipse arg}) GenericTSPL
画椭圆
inherited
gap({required bool enable}) GenericTSPL
定位缝隙
inherited
getRibbonEnd() GenericTSPL
获取当前碳尾开关(0关,1开)
inherited
image({required TImage arg}) GenericTSPL
打印图片
inherited
label({int height = 3, int offset = 0}) GenericTSPL
标签纸打印
inherited
line({required TLine arg}) GenericTSPL
画线(能画斜线)
inherited
mddle() GenericTSPL
inherited
models() GenericTSPL
热转印的型号获取
inherited
newline() GenericTSPL
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset({int offset = 0}) GenericTSPL
进纸
inherited
page({required TPage arg}) GenericTSPL
创建标签页面大小
inherited
peel({required bool enable}) GenericTSPL
是否剥去
inherited
print({int copies = 1}) GenericTSPL
打印标签 @param copies 打印份数
inherited
push(Arg command) GenericTSPL
inherited
putImage({required TPutImage arg}) GenericTSPL
打印打印机里缓存的图片
inherited
qrcode({required TQRCode arg}) GenericTSPL
二维码
inherited
raw(Raw raw) GenericTSPL
inherited
read({ReadOptions? options}) Stream<Uint8List>
inherited
reference({int horizontal = 0, int vertical = 0}) GenericTSPL
相对偏移
inherited
reverse({required TReverse arg}) GenericTSPL
反色
inherited
ribbon({required bool enable}) GenericTSPL
热敏模式
inherited
selfTest() GenericTSPL
打印自检页
inherited
setBlack() GenericTSPL
黑色打印
inherited
setRed({required int density}) GenericTSPL
红色打印(0-15)
inherited
setRibbonEnd(bool enable) GenericTSPL
设置碳尾开关
inherited
shift({int shift = 0}) GenericTSPL
垂直偏移
inherited
sn() GenericTSPL
查询SN
inherited
sns() GenericTSPL
热转印的sn获取
inherited
speed({required int speed}) GenericTSPL
设置速度
inherited
state() GenericTSPL
查询状态
inherited
status() GenericTSPL
查询状态(热敏机器)
inherited
sversion() String
inherited
tear({required bool enable}) GenericTSPL
是否撕去
inherited
text({required TText arg}) GenericTSPL
打印文本
inherited
textBox({required TTextBox arg}) GenericTSPL
打印文本框
inherited
toString() String
A string representation of this object.
inherited
variable(String name, Object value) → PSDK<PSDK>
inherited
version() GenericTSPL
查询版本
inherited
versions() GenericTSPL
热转印的版本号获取
inherited
write({WriteOptions? options}) Future<WroteReporter>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited