TCodeType enum

Inheritance
Available extensions

Values

code128 → const TCodeType
code39 → const TCodeType
code93 → const TCodeType
itf → const TCodeType
upca → const TCodeType
upce → const TCodeType
codeBar → const TCodeType
ean8 → const TCodeType
ean13 → const TCodeType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getType() String

Available on TCodeType, provided by the CodeTypeExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TCodeType>
A constant List of the values in this enum, in order of their declaration.