TFont enum

Inheritance
Available extensions

Values

tss12 → const TFont
tss16 → const TFont
tss20 → const TFont
tss24 → const TFont
tss28 → const TFont
tss32 → const TFont

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFont() String

Available on TFont, provided by the FontExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TFont>
A constant List of the values in this enum, in order of their declaration.