TLineM enum

Inheritance
Available extensions

Values

solidLine → const TLineM
dottedLineM1 → const TLineM
dottedLineM2 → const TLineM
dottedLineM3 → const TLineM
dottedLineM4 → const TLineM

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLine() String

Available on TLineM, provided by the LineMExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TLineM>
A constant List of the values in this enum, in order of their declaration.